import React, { useState } from "react";
import ProcessCreator from "./processCreator";
import ProcessAnimator from "./processAnimator";

interface ArmBotState {
  uuid: string;
  position: [number, number, number];
  rotation: [number, number, number];
  status: string;
  material: string;
  triggerId: string;
  connections: {
      source: { modelUUID: string; pointUUID: string };
      targets: { modelUUID: string; pointUUID: string }[];
  };
  actions: { uuid: string; name: string; speed: number; processes: { triggerId: string; startPoint: string; endPoint: string }[]; };
  isActive?: boolean;
}

interface ProcessContainerProps {
  processes: any[];
  setProcesses: React.Dispatch<React.SetStateAction<any[]>>;
  agvRef: any;
  MaterialRef: any;
  armBots: ArmBotState[];
  setArmBots: React.Dispatch<React.SetStateAction<ArmBotState[]>>;
}

const ProcessContainer: React.FC<ProcessContainerProps> = ({
  processes,
  setProcesses,
  agvRef,
  MaterialRef,
  armBots,
  setArmBots
}) => {
  return (
    <>
      <ProcessCreator onProcessesCreated={setProcesses} />
      <ProcessAnimator
        processes={processes}
        setProcesses={setProcesses}
        agvRef={agvRef}
        MaterialRef={MaterialRef}
        armBots={armBots}
        setArmBots={setArmBots}
      />
    </>
  );
};

export default ProcessContainer;
