import { useState, useRef } from "react";
import * as THREE from "three";
import PathCreation from "./path/pathCreation";
import PathConnector from "./path/pathConnector";
import useModuleStore from "../../store/useModuleStore";
import ProcessContainer from "./process/processContainer";
import Agv from "../builder/agv/agv";
import ArmBot from "./armbot/ArmBot";
import StaticMachine from "./staticMachine/staticMachine";

interface ArmBotState {
    uuid: string;
    position: [number, number, number];
    rotation: [number, number, number];
    status: string;
    material: string;
    triggerId: string;
    connections: {
        source: { modelUUID: string; pointUUID: string };
        targets: { modelUUID: string; pointUUID: string }[];
    };
    actions: { uuid: string; name: string; speed: number; processes: { triggerId: string; startPoint: string; endPoint: string }[]; };
    isActive?: boolean;
}

interface StaticMachineState {
    uuid: string;
    status: string;
    actions: { uuid: string; name: string; buffer: number; material: string; };
    machineTriggerId: string;
    connectedArmBot: string;
}

function Simulation() {
    const { activeModule } = useModuleStore();
    const pathsGroupRef = useRef() as React.MutableRefObject<THREE.Group>;
    const [armBots, setArmBots] = useState<ArmBotState[]>([]);
    const [staticMachines, setStaticMachines] = useState<StaticMachineState[]>([]);
    const [processes, setProcesses] = useState<any[]>([]);
    const agvRef = useRef([]);
    const MaterialRef = useRef([]);

    return (
        <>
            {activeModule === "simulation" && (
                <>
                    <PathCreation pathsGroupRef={pathsGroupRef} />

                    <PathConnector pathsGroupRef={pathsGroupRef} />

                    <ProcessContainer
                        processes={processes}
                        setProcesses={setProcesses}
                        agvRef={agvRef}
                        MaterialRef={MaterialRef}
                        armBots={armBots}
                        setArmBots={setArmBots}
                    />

                    <Agv
                        processes={processes}
                        agvRef={agvRef}
                        MaterialRef={MaterialRef}
                    />

                </>
            )}
            <StaticMachine setArmBots={setArmBots} staticMachines={staticMachines} setStaticMachines={setStaticMachines} />
            <ArmBot armBots={armBots} setArmBots={setArmBots} setStaticMachines={setStaticMachines} />
        </>
    );
}

export default Simulation;
