import React, { useEffect } from 'react'
import { useAnimationPlaySpeed } from '../../../store/usePlayButtonStore';

interface StaticMachineState {
    uuid: string;
    status: string;
    actions: { uuid: string; name: string; buffer: number; material: string; };
    machineTriggerId: string;
    connectedArmBot: string;
}

type StaticMachineInstancesProps = {
    machine: StaticMachineState,
    updateArmBotTriggerAndMachineStatus: (armBotUuid: string, triggerId: string, machineId: string) => void;
}

function StaticMachineInstances({ machine, updateArmBotTriggerAndMachineStatus }: StaticMachineInstancesProps) {
    const { speed } = useAnimationPlaySpeed();

    useEffect(() => {
        if (machine.status === 'running') {
            setTimeout(() => {
                updateArmBotTriggerAndMachineStatus(machine.connectedArmBot, machine.machineTriggerId, machine.uuid);
            }, machine.actions.buffer * 1000 * speed);
        }
    }, [machine])

    return (
        <></>
    )
}

export default StaticMachineInstances