
interface PathConnection {
    fromModelUUID: string;
    fromUUID: string;
    toConnections: {
        toModelUUID: string;
        toUUID: string;
    }[];
}

interface ConnectionStore {
    connections: PathConnection[];
    setConnections: (connections: PathConnection[]) => void;
    addConnection: (newConnection: PathConnection) => void;
    removeConnection: (fromUUID: string, toUUID: string) => void;
}

interface ConveyorEventsSchema {
    modeluuid: string;
    modelName: string;
    type: "Conveyor";
    points: {
        uuid: string;
        position: [number, number, number];
        rotation: [number, number, number];
        actions: { uuid: string; name: string; type: string; material: string; delay: number | string; spawnInterval: number | string; isUsed: boolean; }[] | [];
        triggers: { uuid: string; name: string; type: string; isUsed: boolean; bufferTime: number; }[] | [];
        connections: {
            source: { modelUUID: string; pointUUID: string };
            targets: { modelUUID: string; pointUUID: string }[];
        };
    }[];
    position: [number, number, number];
    rotation: [number, number, number];
    speed: number | string;
}

interface VehicleEventsSchema {
    modeluuid: string;
    modelName: string;
    type: "Vehicle";
    points: {
        uuid: string;
        position: [number, number, number];
        rotation: [number, number, number];
        actions: { uuid: string; name: string; type: string; start: { x: number; y: number } | {}; hitCount: number; end: { x: number; y: number } | {}; buffer: number; };
        connections: {
            source: { modelUUID: string; pointUUID: string };
            targets: { modelUUID: string; pointUUID: string }[];
        };
        speed: number;
        isPlaying: boolean;
    };

    position: [number, number, number];
    rotation: [number, number, number];
}

interface StaticMachineEventsSchema {
    modeluuid: string;
    modelName: string;
    type: "StaticMachine";
    points: {
        uuid: string;
        position: [number, number, number];
        rotation: [number, number, number];
        actions: { uuid: string; name: string; buffer: number; material: string; };
        triggers: { uuid: string; name: string; type: string };
        connections: {
            source: { modelUUID: string; pointUUID: string };
            targets: { modelUUID: string; pointUUID: string }[];
        };
    };
    position: [number, number, number];
    rotation: [number, number, number];
}

interface ArmBotEventsSchema {
    modeluuid: string;
    modelName: string;
    type: "ArmBot";
    points: {
        uuid: string;
        position: [number, number, number];
        rotation: [number, number, number];
        actions: { uuid: string; name: string; speed: number; processes: { triggerId: string; startPoint: string; endPoint: string }[]; };
        triggers: { uuid: string; name: string; type: string };
        connections: {
            source: { modelUUID: string; pointUUID: string };
            targets: { modelUUID: string; pointUUID: string }[];
        };
    };
    position: [number, number, number];
    rotation: [number, number, number];
}

export type EventData = {
    modeluuid: string;
    modelname: string;
    position: [number, number, number];
    rotation: { x: number; y: number; z: number };
    modelfileID: string;
    isLocked: boolean;
    isVisible: boolean;
    eventData?:
    {
        type: "Conveyor";
        points: {
            uuid: string;
            position: [number, number, number];
            rotation: [number, number, number];
            actions: { uuid: string; name: string; type: string; material: string; delay: number | string; spawnInterval: number | string; isUsed: boolean; }[] | [];
            triggers: { uuid: string; name: string; type: string; isUsed: boolean; bufferTime: number; }[] | [];
            connections: {
                source: { modelUUID: string; pointUUID: string };
                targets: { modelUUID: string; pointUUID: string }[];
            };
        }[];
        speed: number | string;
    }
    | {
        type: "Vehicle";
        points: {
            uuid: string;
            position: [number, number, number];
            rotation: [number, number, number];
            actions: { uuid: string; name: string; type: string; start: { x: number; y: number } | {}; hitCount: number; end: { x: number; y: number } | {}; buffer: number; };
            connections: {
                source: { modelUUID: string; pointUUID: string };
                targets: { modelUUID: string; pointUUID: string }[];
            };
            speed: number;
        };
    }
    | {
        type: "StaticMachine";
        points: {
            uuid: string;
            position: [number, number, number];
            rotation: [number, number, number];
            actions: { uuid: string; name: string; buffer: number; material: string; };
            triggers: { uuid: string; name: string; type: string };
            connections: {
                source: { modelUUID: string; pointUUID: string };
                targets: { modelUUID: string; pointUUID: string }[];
            };
        };
    }
    | {
        type: "ArmBot";
        points: {
            uuid: string;
            position: [number, number, number];
            rotation: [number, number, number];
            actions: { uuid: string; name: string; speed: number; processes: { triggerId: string; startPoint: string; endPoint: string; }[]; };
            triggers: { uuid: string; name: string; type: string };
            connections: {
                source: { modelUUID: string; pointUUID: string };
                targets: { modelUUID: string; pointUUID: string }[];
            };
        };
    };
};
